Compute Wald confidence intervals for mean structure parameters of geelm object.
# S3 method for geelm
confint(object, parm = NULL, level = 0.95, std.err = "san.se", ...)# S3 method for geeglm
confint(object, parm = NULL, level = 0.95, std.err = "san.se", ...)
A matrix (or vector) with columns giving lower and upper confidence limits for each parameter.
a fitted model object.
specification of which parameters are to be given confidence intervals, either a vector of numbers or a vector of names. If missing, all parameters are considered.
the confidence level required.
Which standard error estimation method that should
be used for computing the confidence intervals. Only san.se
is supported for geelm objects but jack, j1s or fij may
be used for geeglm objects (if they have been estimated when
fitting the model).
additional argument(s) for methods.
confint(geeglm):