An object of class anova summarizing the differences in
fit between the models.
Arguments
object
a fitted object of class geese.
scope
a formula giving the terms to be considered for adding
or dropping.
test
the type of test to include.
method
Indicates which method is used for computing the
standard error. robust is the default and corresponds to
the modified sandwich estimator. naive is the classical
naive variance estimate. sandwich is an alias for
robust.