An object of class geelm (inherits from geeglm) representing the fit.
It contains the following slots:
$coefficients: Coefficients from the mean structure model (betas) on their
original scales
$residuals: Pearson residuals, in the order of the inputted dataset (with NAs omitted).
$fitted.values: Fitted values (response scale), in the order of the inputted dataset
(with NAs omitted).
$rank: The rank of the model matrix, i.e. the number of estimated mean structure
coefficients.
$qr: QR decomposition of the model matrix (NA omitted).
$family: A family object specifying which exponential family was used for fitting
the mean structure model, see family for more information.
$linear.predictors: The linear predictor on the original scale.
$weights: Weights used for computations, in the order of the inputted dataset
(NAs omitted).
$prior.weights: The original weights used to produce this geeglm object (set
by user or defaulted to 1 for all observations).
$df.residuals: Residual degrees of freedom.
$y: Outcome variable, in the order of the inputted dataset (NAs omitted).
$model: The model.frame, ordered as the original inputted data with NAs omitted.
$call: The original function call that produced this geeglm object.
$formula: The formula used in the original call.
$terms: The terms of the formula used in the original call.
$data: The original dataset that was used for producing this geeglm object.
$offset: Offset used for fitting the model, ordered as the
original inputted data with NAs omitted.
$control: Value of control parameters used for fitting the
model.
$method: Internal function used for fitting the model.
$contrasts: Contrasts used in the model matrix.
$xlevels: Levels of factor variables used in the model
formula (if any).
$geese: An object containing further information about the
variance estimation, including a variance matrix for the
beta-coefficients ($vbeta), the estimated coefficients for
the working correlation matrix ($alpha), the estimated
dispersion parameter ($gamma), and the individual cluster
sizes ($clusz). See geese for more
information.
$modelInfo: Information about the link functions used for
fitting the mean, variance and scale structures of the model.
$id: IDs used for identifying the clusters, ordered as the
original inputted data with NAs omitted.
$corstr: Name of the correlation structured imposed on the
model. If the correlation structure requires further information,
it is stored in a suitably named attribute. For example, for
m-dependent correlation structures, the m scalar is available in an
attribute named Mv.
$cor.link: Link function used for the correlation structure.
$std.err: Method used to estimate the standard error of the mean structure
coefficients (betas).